@@ -41,7 +41,7 @@ class CLI(BaseCLI):
                 help="Min value of eps_t (force dev) to select new configs from")
         self.parser.add_argument("--hi", type=float, default=0.35,
                 help="Max value of eps_t (force dev) to select new configs from")
-        self.parser.add_argument("-o", "--output", nargs=1, type=str, default="new_configs.traj",
+        self.parser.add_argument("-o", "--output", type=str, default="new_configs.traj",
                 help="File to write new configurations to")
         self.parser.add_argument("-p", "--plot-dev", action="store_true",
                 help="Plot histogram of max force deviation of model ensemble for each config")
@@ -71,7 +71,8 @@ class CLI(BaseCLI):
             if ensemble is not None and len(ensemble) == 1:
                 load(ensemble[0])
             defaults = get_dpfaults(key="ensemble")
-            self.type_map, *ensemble = defaults
+            #self.type_map, *ensemble = defaults
+            *ensemble, self.type_map = defaults
         else:
             self.type_map = graph2typemap(ensemble[0])
         self.ensemble = ensemble
